;; Generated package description from bash-completion.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "bash-completion" "3.2.1snapshot0.20260325.162703" "Bash completion for the shell buffer" '((emacs "25.3")) :commit "e2ae243588db8e03f4d0485bb09b670abbc63eaf" :authors '(("Stephane Zermatten" . "szermatt@gmx.net")) :maintainer '("Stephane Zermatten" . "szermatt@gmail.com") :keywords '("convenience" "unix") :url "http://github.com/szermatt/emacs-bash-completion")
